*******
History
*******

v{{ cookiecutter.version }} ({% now 'local' %})
===============================================

This package was created with package `et-micc <https://github.com/etijskens/et-micc>`_,
